# Reporting Framework and CLI
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/reporting-framework-and-cli#overview)
  * [Reporting Framework](https://help.sap.com/docs/leanix/ea/reporting-framework-and-cli#reporting-framework)
  * [Reporting CLI](https://help.sap.com/docs/leanix/ea/reporting-framework-and-cli#reporting-cli)
  * [Required Knowledge](https://help.sap.com/docs/leanix/ea/reporting-framework-and-cli#required-knowledge)
  * [Tutorials](https://help.sap.com/docs/leanix/ea/reporting-framework-and-cli#tutorials)


Build custom reports using the LeanIX Reporting Framework and CLI.
